<?php
/**
 * @file
 * accounting_base.rules_defaults.inc
 */

/**
 * Implements hook_default_rules_configuration().
 */
function accounting_base_default_rules_configuration() {
  $items = array();
  $items['rules_after_a_transaction_has_been_deleted'] = entity_import('rules_config', '{ "rules_after_a_transaction_has_been_deleted" : {
      "LABEL" : "After a transaction has been deleted",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_delete--transaction" : { "bundle" : "transaction" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "entity_delete" : { "data" : [ "node:field-part-from" ] } },
        { "entity_delete" : { "data" : [ "node:field-part-to" ] } }
      ]
    }
  }');
  $items['rules_after_existing_transaction_has_been_updated'] = entity_import('rules_config', '{ "rules_after_existing_transaction_has_been_updated" : {
      "LABEL" : "After existing transaction has been updated",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_update--transaction" : { "bundle" : "transaction" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_update_transaction_parts" : { "transaction_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_after_saving_a_new_account'] = entity_import('rules_config', '{ "rules_after_saving_a_new_account" : {
      "LABEL" : "After saving a new account",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_insert" : [] },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_assign_trail_for_account" : { "account_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_after_saving_a_new_transaction'] = entity_import('rules_config', '{ "rules_after_saving_a_new_transaction" : {
      "LABEL" : "After saving a new transaction",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_insert--transaction" : { "bundle" : "transaction" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "part",
              "param_title" : "Part ID [node:nid]",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "created_part_from" : "Created Part from" } }
          }
        },
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "part",
              "param_title" : "Part ID [node:nid]",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "created_part_to" : "Created Part to" } }
          }
        },
        { "entity_save" : { "data" : [ "created-part-from" ], "immediate" : "1" } },
        { "entity_save" : { "data" : [ "created-part-to" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "created-part-from:field-transaction" ],
            "value" : [ "node" ]
          }
        },
        { "data_set" : { "data" : [ "created-part-to:field-transaction" ], "value" : [ "node" ] } },
        { "data_set" : {
            "data" : [ "created-part-from:field-part" ],
            "value" : [ "created-part-to" ]
          }
        },
        { "data_set" : {
            "data" : [ "created-part-to:field-part" ],
            "value" : [ "created-part-from" ]
          }
        },
        { "data_set" : { "data" : [ "node:field-part-from" ], "value" : [ "created-part-from" ] } },
        { "data_set" : { "data" : [ "node:field-part-to" ], "value" : [ "created-part-to" ] } },
        { "component_rules_update_transaction_parts" : { "transaction_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_after_updating_existing_content_of_type_account'] = entity_import('rules_config', '{ "rules_after_updating_existing_content_of_type_account" : {
      "LABEL" : "After updating existing content of type account",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_update" : [] },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_assign_trail_for_account" : { "account_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_assign_trail_for_account'] = entity_import('rules_config', '{ "rules_assign_trail_for_account" : {
      "LABEL" : "Assign trail for Account",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "account_node" : { "label" : "Account node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "account-node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        },
        { "NOT data_is_empty" : { "data" : [ "account-node:field-reporting-hierarchy" ] } },
        { "entity_is_of_bundle" : {
            "entity" : [ "account-node:field-reporting-hierarchy" ],
            "type" : "taxonomy_term",
            "bundle" : { "value" : { "reporting_hierarchy" : "reporting_hierarchy" } }
          }
        }
      ],
      "DO" : [
        { "data_set" : {
            "data" : [ "account-node:field-trail" ],
            "value" : [ "account-node:field-reporting-hierarchy:parents-all" ]
          }
        }
      ]
    }
  }');
  $items['rules_clone_account'] = entity_import('rules_config', '{ "rules_clone_account" : {
      "LABEL" : "Clone account",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "account_node" : { "label" : "Account node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "account-node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "account",
              "param_title" : "Temp account title",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:title" ],
            "value" : "[account-node:title] [CLONED]"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-reporting-hierarchy" ],
            "value" : [ "account-node:field-reporting-hierarchy" ]
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "redirect" : {
            "url" : "node\\/[entity-created:nid]\\/edit?destination=[site:current-page:path]",
            "destination" : "1"
          }
        }
      ]
    }
  }');
  $items['rules_clone_transaction'] = entity_import('rules_config', '{ "rules_clone_transaction" : {
      "LABEL" : "Clone transaction",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules", "rules_conditional" ],
      "USES VARIABLES" : { "transaction_node" : { "label" : "Transaction node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "transaction",
              "param_title" : "Transaction NID [node:nid]",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:field-date" ],
            "value" : [ "transaction-node:field-date" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-note" ],
            "value" : "[transaction-node:field-note] CLONE"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-amount" ],
            "value" : [ "transaction-node:field-amount" ]
          }
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "NOT data_is_empty" : { "data" : [ "transaction-node:field-from" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "entity-created:field-from" ],
                    "value" : [ "transaction-node:field-from" ]
                  }
                }
              ]
            },
            { "ELSE" : [ { "data_set" : { "data" : [ "entity-created:field-from" ] } } ] }
          ]
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "NOT data_is_empty" : { "data" : [ "transaction-node:field-to" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "entity-created:field-to" ],
                    "value" : [ "transaction-node:field-to" ]
                  }
                }
              ]
            },
            { "ELSE" : [ { "data_set" : { "data" : [ "entity-created:field-to" ] } } ] }
          ]
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "redirect" : {
            "url" : "node\\/[entity-created:nid]\\/edit?destination=[site:current-page:path]",
            "destination" : "1"
          }
        }
      ]
    }
  }');
  $items['rules_link_condition_clone_account_button'] = entity_import('rules_config', '{ "rules_link_condition_clone_account_button" : {
      "LABEL" : "Rules link: Clone account button condition",
      "PLUGIN" : "and",
      "OWNER" : "rules",
      "USES VARIABLES" : { "node" : { "type" : "node", "label" : "node" } },
      "AND" : []
    }
  }');
  $items['rules_link_condition_clone_transaction_button'] = entity_import('rules_config', '{ "rules_link_condition_clone_transaction_button" : {
      "LABEL" : "Rules link: Clone transaction button condition",
      "PLUGIN" : "and",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "node" : { "label" : "node", "type" : "node" } },
      "AND" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ]
    }
  }');
  $items['rules_link_set_clone_account_button'] = entity_import('rules_config', '{ "rules_link_set_clone_account_button" : {
      "LABEL" : "Rules link: Clone account button rules set",
      "PLUGIN" : "rule set",
      "OWNER" : "rules",
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "node" : { "type" : "node", "label" : "node" } },
      "RULES" : [
        { "RULE" : {
            "IF" : [
              { "entity_is_of_bundle" : {
                  "entity" : [ "node" ],
                  "type" : "node",
                  "bundle" : { "value" : { "account" : "account" } }
                }
              }
            ],
            "DO" : [ { "component_rules_clone_account" : { "account_node" : [ "node" ] } } ],
            "LABEL" : "Clone account button rule"
          }
        }
      ]
    }
  }');
  $items['rules_link_set_clone_transaction_button'] = entity_import('rules_config', '{ "rules_link_set_clone_transaction_button" : {
      "LABEL" : "Rules link: Clone transaction button rules set",
      "PLUGIN" : "rule set",
      "OWNER" : "rules",
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "node" : { "type" : "node", "label" : "node" } },
      "RULES" : [
        { "RULE" : {
            "IF" : [
              { "entity_is_of_bundle" : {
                  "entity" : [ "node" ],
                  "type" : "node",
                  "bundle" : { "value" : { "transaction" : "transaction" } }
                }
              }
            ],
            "DO" : [
              { "component_rules_clone_transaction" : { "transaction_node" : [ "node" ] } }
            ],
            "LABEL" : "Clone transaction button rule"
          }
        }
      ]
    }
  }');
  $items['rules_update_transaction_parts'] = entity_import('rules_config', '{ "rules_update_transaction_parts" : {
      "LABEL" : "Update transaction parts",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules", "rules_conditional" ],
      "USES VARIABLES" : { "transaction_node" : { "label" : "Transaction node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        },
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node:field-part-from" ],
            "type" : "node",
            "bundle" : { "value" : { "part" : "part" } }
          }
        },
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node:field-part-to" ],
            "type" : "node",
            "bundle" : { "value" : { "part" : "part" } }
          }
        }
      ],
      "DO" : [
        { "data_calc" : {
            "USING" : {
              "input_1" : [ "transaction-node:field-amount" ],
              "op" : "*",
              "input_2" : "-1"
            },
            "PROVIDE" : { "result" : { "result" : "Calculation result" } }
          }
        },
        { "data_set" : {
            "data" : [ "transaction-node:field-part-from:field-amount" ],
            "value" : [ "result" ]
          }
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "data_is_empty" : { "data" : [ "transaction-node:field-from" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-from:field-account" ],
                    "value" : [ "" ]
                  }
                }
              ]
            },
            { "ELSE" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-from:field-account" ],
                    "value" : [ "transaction-node:field-from" ]
                  }
                }
              ]
            }
          ]
        },
        { "entity_save" : { "data" : [ "transaction-node:field-part-from" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "transaction-node:field-part-to:field-amount" ],
            "value" : [ "transaction-node:field-amount" ]
          }
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "data_is_empty" : { "data" : [ "transaction-node:field-to" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-to:field-account" ],
                    "value" : [ "" ]
                  }
                }
              ]
            },
            { "ELSE" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-to:field-account" ],
                    "value" : [ "transaction-node:field-to" ]
                  }
                }
              ]
            }
          ]
        },
        { "entity_save" : { "data" : [ "transaction-node:field-part-to" ], "immediate" : "1" } }
      ]
    }
  }');
  return $items;
}
